@@ -6,6 +6,7 @@ from rsack import bugs, genie, qobuz
 from rsack.utils import bugs_id, genie_id, Settings
 
 def get_args():
+    """Generate arguments"""
     parser = ArgumentParser()
     parser.add_argument('-v', '--version', action='store_true', dest='version', required=False)
     parser.add_argument('-b', '--bugs', action='store_true', dest="bugs", required=False)
@@ -18,6 +19,7 @@ def get_args():
 
     
 def main():
+    """Entry point"""
     args = get_args()
     if args.version:
         print(__version__)
@@ -27,11 +29,11 @@ def main():
         for url in args.url:
             id = bugs_id(url)
             if "album" in url:
-                bugs.Download(type="album", id=id)
+                bugs.Download(type="album", id=int(id))
             elif "artist" in url:
-                bugs.Download(type="artist", id=id)
+                bugs.Download(type="artist", id=int(id))
             elif "track" in url:
-                bugs.Download(type="Single tracks not yet available", id=id)
+                bugs.Download(type="Single tracks not yet available", id=int(id))
     elif args.genie:
         for url in args.url:
             match = genie_id(url)
