@@ -103,7 +103,7 @@ def track_to_flac(track: dict, album: dict, lyrics: str) -> dict:
     """
     meta = {
         "ALBUM": track['album_title'],
-        "ALBUMARTIST": track['artist_disp_nm'],
+        "ALBUMARTIST": album['artist_disp_nm'],
         "ARTIST": track['artist_disp_nm'],
         "TITLE": track['track_title'],
         "DISCNUMBER": str(track['disc_id']),
@@ -113,7 +113,7 @@ def track_to_flac(track: dict, album: dict, lyrics: str) -> dict:
         "COMMENT": str(track['track_id']),
         "DATE": _format_date(track['release_ymd']),
         "GENRE": album['genre_str'],
-        "LABEL": "",
+        "LABEL": '; '.join(str(label['label_nm']) for label in album['labels']),
         "LYRICS": lyrics
     }
     return meta
@@ -130,12 +130,6 @@ def _format_date(date):
         except ValueError:
             pass
 
-def determine_quality(svc_flac_yn: str) -> str:
-    if svc_flac_yn == 'Y':
-        return 'flac'
-    else:
-        return 'mp3'
-
 def bugs_id(url: str) -> str:
     return match(
         r'https?://music\.bugs\.co\.kr/(?:(?:album|artist|track|playlist)/|[a-z]{2}-[a-z]{2}-?\w+(?:-\w+)*-?)(\w+)',url).group(1)
